@@ -76,13 +76,20 @@ def test_statement_condition_remove_colon():
     assert StatementCondition.parse_obj(
         {
             "ForAllValues:ArnEqualsIfExists": {"patata_1": "test_1"},
-            "ForAnyValue:ARNEquals": {"patata_2": ["test_2", "test_3"]},
+            "ForAnyValue:ArnEquals": {"patata_2": ["test_2", "test_3"]},
         }
     ) == StatementCondition(
-        ForAllValuesArnEqualsIfExists={"patata_1": "test_1"}, ForAnyValueARNEquals={"patata_2": ["test_2", "test_3"]}
+        ForAllValuesArnEqualsIfExists={"patata_1": "test_1"}, ForAnyValueArnEquals={"patata_2": ["test_2", "test_3"]}
     )
 
 
+def test_eval_is_built_only_if_called():
+    condition = StatementCondition()
+    assert condition._eval is None
+    condition.eval({})
+    assert condition._eval is not None
+
+
 @pytest.mark.parametrize(
     "function, arg_a, arg_b, params, expected_output",
     [
@@ -514,6 +521,13 @@ def test_build_evaluator_binary_equals(function: str, arg_a: Any, arg_b: Any, pa
     [
         ("NumericEquals", {"patata": 1}, {"patata": 1}, True),
         ("NumericEquals", {"patata": 1}, {"patata": 2}, False),
+        ("StringEquals", {"patata": ["1", "2", "3"]}, {"patata": ["2", "1"]}, True),
+        ("StringEquals", {"patata": ["1", "2", "3"]}, {"patata": ["1", "3"]}, True),
+        ("StringEquals", {"patata": "2"}, {"patata": ["2"]}, False),
+        ("StringEquals", {"patata": "2"}, {"patata": ["2", "1"]}, False),
+        ("StringEquals", {"patata": ["1", "3"]}, {"patata": ["4"]}, False),
+        ("StringLike", {"patata": ["sky*"]}, {"patata": ["skyx", "skyscanner", "nope"]}, True),
+        ("StringLike", {"patata": ["sky*"]}, {"patata": ["nopeskyx", "nopeskyscanner", "nope"]}, False),
     ],
 )
 def test_build_root_evaluator(function: str, arguments: Union[Dict, Tuple], params: Dict, expected_output: bool):
